==> node-codemirror_6.33.0+~cs119.71.50.orig-codemirror-commands.tar.gz: commands-6.6.0/src/README.md <==
This package exports a collection of generic editing commands, along
with key bindings for a lot of them.

### Keymaps

@standardKeymap

@defaultKeymap

@emacsStyleKeymap

@indentWithTab

### Selection

@simplifySelection

#### By character

@cursorCharLeft

@selectCharLeft

@cursorCharRight

@selectCharRight

@cursorCharForward

@selectCharForward

@cursorCharBackward

@selectCharBackward

#### By group

@cursorGroupLeft

@selectGroupLeft

@cursorGroupRight

@selectGroupRight

@cursorGroupForward

@selectGroupForward

@cursorGroupBackward

@selectGroupBackward

@cursorSubwordForward

@selectSubwordForward

@cursorSubwordBackward

@selectSubwordBackward

#### Vertical motion

@cursorLineUp

@selectLineUp

@cursorLineDown

@selectLineDown

@cursorPageUp

@selectPageUp

@cursorPageDown

@selectPageDown

#### By line boundary

@cursorLineBoundaryForward

@selectLineBoundaryForward

@cursorLineBoundaryBackward

@selectLineBoundaryBackward

@cursorLineBoundaryLeft

@selectLineBoundaryLeft

@cursorLineBoundaryRight

@selectLineBoundaryRight

@cursorLineStart

@selectLineStart

@cursorLineEnd

@selectLineEnd

@selectLine

#### By document boundary

@cursorDocStart

@selectDocStart

@cursorDocEnd

@selectDocEnd

@selectAll

#### By syntax

@cursorSyntaxLeft

@selectSyntaxLeft

@cursorSyntaxRight

@selectSyntaxRight

@selectParentSyntax

@cursorMatchingBracket

@selectMatchingBracket

### Deletion

@deleteCharBackward

@deleteCharBackwardStrict

@deleteCharForward

@deleteGroupBackward

@deleteGroupForward

@deleteToLineStart

@deleteToLineEnd

@deleteLineBoundaryBackward

@deleteLineBoundaryForward

@deleteTrailingWhitespace

### Line manipulation

@splitLine

@moveLineUp

@moveLineDown

@copyLineUp

@copyLineDown

@deleteLine

### Indentation

@indentSelection

@indentMore

@indentLess

@insertTab

### Character Manipulation

@transposeChars

@insertNewline

@insertNewlineAndIndent

@insertNewlineKeepIndent

@insertBlankLine

### Undo History

@history

@historyKeymap

@historyField

@undo

@redo

@undoSelection

@redoSelection

@undoDepth

@redoDepth

@isolateHistory

@invertedEffects

### Commenting and Uncommenting

@CommentTokens

@toggleComment

@toggleLineComment

@lineComment

@lineUncomment

@toggleBlockComment

@blockComment

@blockUncomment

@toggleBlockCommentByLine

### Tab Focus Mode

@toggleTabFocusMode

@temporarilySetTabFocusMode

==> node-codemirror_6.38.1+~cs119.80.67.orig-codemirror-commands.tar.gz: commands-6.8.1/src/README.md <==
This package exports a collection of generic editing commands, along
with key bindings for a lot of them.

### Keymaps

@standardKeymap

@defaultKeymap

@emacsStyleKeymap

@indentWithTab

### Selection

@simplifySelection

#### By character

@cursorCharLeft

@selectCharLeft

@cursorCharRight

@selectCharRight

@cursorCharForward

@selectCharForward

@cursorCharBackward

@selectCharBackward

@cursorCharForwardLogical

@selectCharForwardLogical

@cursorCharBackwardLogical

@selectCharBackwardLogical

#### By group

@cursorGroupLeft

@selectGroupLeft

@cursorGroupRight

@selectGroupRight

@cursorGroupForward

@selectGroupForward

@cursorGroupBackward

@selectGroupBackward

@cursorGroupForwardWin

@selectGroupForwardWin

@cursorSubwordForward

@selectSubwordForward

@cursorSubwordBackward

@selectSubwordBackward

#### Vertical motion

@cursorLineUp

@selectLineUp

@cursorLineDown

@selectLineDown

@cursorPageUp

@selectPageUp

@cursorPageDown

@selectPageDown

#### By line boundary

@cursorLineBoundaryForward

@selectLineBoundaryForward

@cursorLineBoundaryBackward

@selectLineBoundaryBackward

@cursorLineBoundaryLeft

@selectLineBoundaryLeft

@cursorLineBoundaryRight

@selectLineBoundaryRight

@cursorLineStart

@selectLineStart

@cursorLineEnd

@selectLineEnd

@selectLine

#### By document boundary

@cursorDocStart

@selectDocStart

@cursorDocEnd

@selectDocEnd

@selectAll

#### By syntax

@cursorSyntaxLeft

@selectSyntaxLeft

@cursorSyntaxRight

@selectSyntaxRight

@selectParentSyntax

@cursorMatchingBracket

@selectMatchingBracket

### Deletion

@deleteCharBackward

@deleteCharBackwardStrict

@deleteCharForward

@deleteGroupBackward

@deleteGroupForward

@deleteToLineStart

@deleteToLineEnd

@deleteLineBoundaryBackward

@deleteLineBoundaryForward

@deleteTrailingWhitespace

### Line manipulation

@splitLine

@moveLineUp

@moveLineDown

@copyLineUp

@copyLineDown

@deleteLine

### Indentation

@indentSelection

@indentMore

@indentLess

@insertTab

### Character Manipulation

@transposeChars

@insertNewline

@insertNewlineAndIndent

@insertNewlineKeepIndent

@insertBlankLine

### Undo History

@history

@historyKeymap

@historyField

@undo

@redo

@undoSelection

@redoSelection

@undoDepth

@redoDepth

@isolateHistory

@invertedEffects

### Commenting and Uncommenting

@CommentTokens

@toggleComment

@toggleLineComment

@lineComment

@lineUncomment

@toggleBlockComment

@blockComment

@blockUncomment

@toggleBlockCommentByLine

### Tab Focus Mode

@toggleTabFocusMode

@temporarilySetTabFocusMode
